Mooeypoo has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/126726

Change subject: Border checkbox disabling/enabling fix
......................................................................

Border checkbox disabling/enabling fix

Due to a lack of clarity in the wikitext documentation the border
checkbox wasn't set up right. This is the proper behavior: border is
allowed for all unframed images (frameless and basic) while the
framed images (frame and thumb) have it anyways. Wikitext
documentation was also clarified for prosperity.

Change-Id: I4dd4775da473d669781553796be99646240c13fe
---
M modules/ve-mw/ui/dialogs/ve.ui.MWMediaEditDialog.js
1 file changed, 2 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/VisualEditor 
refs/changes/26/126726/1

diff --git a/modules/ve-mw/ui/dialogs/ve.ui.MWMediaEditDialog.js 
b/modules/ve-mw/ui/dialogs/ve.ui.MWMediaEditDialog.js
index fadbe71..5616cd5 100644
--- a/modules/ve-mw/ui/dialogs/ve.ui.MWMediaEditDialog.js
+++ b/modules/ve-mw/ui/dialogs/ve.ui.MWMediaEditDialog.js
@@ -368,10 +368,10 @@
                this.scalable.setEnforcedMax( false );
        }
 
        // Disable border checkbox for framed images
        // According to documentation:
        // https://en.wikipedia.org/wiki/Wikipedia:Extended_image_syntax#Border
-       if ( selectedType === 'frame' ) {
+       if ( selectedType === 'thumb' || selectedType === 'frame' ) {
                // Disable border option
                this.borderCheckbox.setDisabled( true );
                this.borderCheckbox.setValue( false );
@@ -368,10 +368,10 @@
        }
 
-       // Disable border checkbox for framed images
+       // Disable border checkbox for thumb and framed images
        // According to documentation:
        // https://en.wikipedia.org/wiki/Wikipedia:Extended_image_syntax#Border

-- 
To view, visit https://gerrit.wikimedia.org/r/126726
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I4dd4775da473d669781553796be99646240c13fe
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/VisualEditor
Gerrit-Branch: master
Gerrit-Owner: Mooeypoo <mor...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to